GridKit
=======

GridKit is a tool to work with grids on a high abstraction level.

[![download stats: PePy](https://static.pepy.tech/personalized-badge/gridkit?period=total&units=international_system&left_color=grey&right_color=blue&left_text=Downloads)](https://pepy.tech/project/gridkit)
[![codecov](https://codecov.io/gh/tmillenaar/GridKit/branch/main/graph/badge.svg?token=23BKSMAHM1)](https://codecov.io/gh/tmillenaar/GridKit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![PyPI](https://badge.fury.io/py/gridkit.svg)](https://pypi.org/project/gridkit/)

Note: the api is likely to change between versions until release 1.x.x

Documentation
=============
Find the docs on [GitHub Pages](https://tmillenaar.github.io/GridKit).

Examples
========
Find examples in the [Example Gallery](https://tmillenaar.github.io/GridKit/example_gallery/index.html) section of the documentation.

Source
======
Find me on [GitHub](https://github.com/tmillenaar/GridKit)

Installation
============
To install through PyPi, run `pip install gridkit`.

Alternatively, install from source ([GitHub](https://github.com/tmillenaar/gridkit)). Please refer to the [Contributing guide](https://tmillenaar.github.io/GridKit/contributing.html)
